﻿using Microsoft.VisualBasic.FileIO;
using ProjectTourismCompany.Entities;
using ProjectTourismCompany.Entities.Enums;
using ProjectTourismCompany.Repositories;
using ProjectTourismCompany.Repositories.Implementations;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourismCompany.Forms;

public partial class FormCompany : Form
{
    private readonly ICompanyRepository _companyRepository;
    private int? _companyId;
    public int Id
    {
        set
        {
            try
            {
                var client = _companyRepository.ReadCompanyById(value);
                if (client == null)
                {
                    throw new InvalidDataException(nameof(client));
                }

                textBoxName.Text = client.Name;
                comboBoxCountry.SelectedItem = client.CountryId;
                _companyId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }




    public FormCompany(
    ICompanyRepository companyRepository,
    ITripRepository tripRepository,
    ICountryRepository countryRepository)
    {
        InitializeComponent();
        _companyRepository = companyRepository ??
        throw new ArgumentNullException(nameof(companyRepository));
        comboBoxCountry.DataSource = countryRepository.ReadCountries();
        comboBoxCountry.DisplayMember = "Name";
        comboBoxCountry.ValueMember = "Id";
        
        ColumnTitle.DataSource = tripRepository.ReadTrips();
        ColumnTitle.DisplayMember = "Title";
        ColumnTitle.ValueMember = "Id";
    }


    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (dataGridView1.RowCount < 1 ||
            comboBoxCountry.SelectedIndex < 0)
            {
            throw new Exception("Имеются незаполненные поля");
            }
            _companyRepository.CreateCompany(Company.CreateCompany(0, textBoxName.Text, (int)comboBoxCountry.SelectedItem!, CreateListCompanyTripFromDataGrid()));
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
    private void ButtonCancel_Click(object sender, EventArgs e) =>
    Close();
    private List<CompanyTrip> CreateListCompanyTripFromDataGrid()
    {
        var list = new List<CompanyTrip>();
        foreach (DataGridViewRow row in dataGridView1.Rows)
        {
            if (row.Cells["ColumnAdditionalPrice"].Value == null ||
            row.Cells["ColumnTitle"].Value == null)
            {
                continue;
            }
            list.Add(CompanyTrip.CreateCompanyTrip(0, 0,
            Convert.ToInt32(row.Cells["ColumnTitle"].Value),
            Convert.ToInt32(row.Cells["ColumnAdditionalPrice"].Value)));
        }
        return list;
    }
}
